@@ -78,13 +78,13 @@ def destination_heuristic(data):
         )
 
     # Find the paths that appears most often
-    sorted_paths = sorted(counter, reverse=True)
-    groupby = itertools.groupby(sorted_paths, key=len)
+    sorted_paths = counter.most_common()
+    groupby = itertools.groupby(sorted_paths, key=lambda x: x[1])
     _, group = next(groupby)
 
     # We know that there's at least one candidate. Make sure it's
     # the only one
-    candidate = next(group)
+    candidate, _ = next(group)
     try:
         next(group)
     except StopIteration:
@@ -230,9 +230,14 @@ def highlight_match(
         extra_match_info = {}
     for key, vals in result.match.items():
         if isinstance(vals, collections.abc.Mapping):
-            inner_result = models.SearchResult(result.entry[key], result.match[key],)
+            inner_result = models.SearchResult(
+                result.entry[key],
+                result.match[key],
+            )
             text, extra_match_info = highlight_match(
-                text, inner_result, extra_match_info,
+                text,
+                inner_result,
+                extra_match_info,
             )
         else:
             for val in vals:
